function [cinput_NOx,cinput_red,cinput_O2,vel_in,Tinput,pressure,density_molar] = inflow_conditions(ncell,time_inflow,cinflow_NOx,cinflow_red,cinflow_O2,P_inflow,T_inflow,cg_NOx,cg_red,cg_O2,Tg,velocity,time)

%Function for determining the inlet conditions for each cell 
%Inlet condition for a given cell = outlet condition of the cell upstream
%Inlet condition for the first cell is determined using inlet specification vectors through
%linear interpolation

%Created by Kalyana Chakravarthy (ORNL), 9/27/2004
%Updated last by Kalyana Chakravarthy (ORNL), 9/27/2004

global Rgas

pressure      = interp1(time_inflow,P_inflow,time); % inlet pressure (Pa)
density_molar = pressure/(Rgas*interp1(time_inflow,T_inflow,time)); %inlet molar density

% Temperature, conc. of NOx, reductant and O2 at the entrances of each cell.

Tinput        = [interp1(time_inflow,T_inflow,time),Tg(1:ncell-1)];

cinput_NOx = [interp1(time_inflow,cinflow_NOx,time)*density_molar,cg_NOx(1:ncell-1)];
cinput_red = [interp1(time_inflow,cinflow_red,time)*density_molar,cg_red(1:ncell-1)];
cinput_O2  = [interp1(time_inflow,cinflow_O2,time)*density_molar,cg_O2(1:ncell-1)];

vel_in        =  interp1(time_inflow,velocity,time); % inlet velocity [m/s]

