function [time,time_end,time_inflow,cinflow_NOx,cinflow_red,cinflow_O2,velocity,T_inflow,P_inflow] = inflow_data

%Function that specifies the inlet conditions (capture-regen scheme)
%Created by Kalyana Chakravarthy (ORNL), 9/27/2004
%Updated last by Kalyana Chakravarthy (ORNL), 9/27/2004

time	   = 1.0e-8; % Starting time [s]
time_end   = 1.6e2;  % Ending time   [s]

n_inflow= 1602;	     % Number of points in time where inlet conditions are specified
                                                                                      
for i = 1:n_inflow

%                               Sample lean conditions

time_inflow(i)  = (i-1)*0.1;	% Time interval for specifying inlet conditions [s]
cinflow_NOx(i)  = 300.0e-6;	% Inflow NOx concentration 			[mole/m^3]
cinflow_red(i)  = 0.0;		% Reductant concentration 			[mole/m^3]
cinflow_O2(i)   = 0.12;		% O2 concentration				[mole/m^3]
velocity(i)     = 1.0;		% average bulk velocity in the channels 	[m/s]
T_inflow(i)	= 273.16 + 317.0;% Inlet gas temperature                        [K]
P_inflow(i)	= 1.01325e5;	% Inlet pressure                                [Pa]
                                                                                      
if(mod(i,600)>550)

%				Sample rich conditions

cinflow_NOx(i)  = 0.0;		% Inflow NOx concentration                      [mole/m^3]
cinflow_red(i)  = 5.0e-3;	% Reductant concentration                       [mole/m^3]
cinflow_O2(i)   = 0.0;		% O2 concentration                              [mole/m^3]
end;

end;
