function[channel_length,hole_fraction,channel_density,density_solid,lambda_solid,Cp_solid_0,Cp_solid_1,Cp_solid_2,wetted_area,channel_diameter,Sh,Nu] = monolith_properties

%Function that defines geometric and physical properties of the monolith 
%Created by Kalyana Chakravarthy (ORNL), 9/27/2004
%Updated last by Kalyana Chakravarthy (ORNL), 9/27/2004

channel_length  = 3.0*0.0254; % [m]
hole_fraction   = 0.743;
channel_density = 310000.0;   % [1/m^2]

density_solid   = 2500.0e0;   % monolith density [kg/m^3]
lambda_solid    = 1.675;      % thermal conductivity of the monolith [J/(m s K)]

Cp_solid_0      = 1071.0;     % specific heat of the monolith [J/(kg K)]
Cp_solid_1      = 0.156;      %	= Cp_solid_0 + C_p_solid_1*T_solid
Cp_solid_2      = 3.435e7;    % - C_p_solid_2/T_solid^2

wetted_area     = 4.0*sqrt(hole_fraction*channel_density); %heat/mass transfer area per unit volume
                                                           %[1/m]

channel_diameter= sqrt(hole_fraction/channel_density);	% [m]
Sh              = 3.0;					% Sherwood number(laminar BL correlation)
Nu              = 3.6;					% Nusselt number (laminar BL correlation)


